        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>14</strong> miembros: 34 <strong>control</strong><br>0,1,5,8,9,11,12,13,14,17,18,21,22,24,25,26,27,28,30,32,33,35,36,38,39,41,42,43,44,45,46,48,49,50';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 17 <br>2,3,4,6,7,10,15,16,19,20,23,29,31,34,37,40,47';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>14</strong> miembros: 34 <strong>control</strong><br>0,1,5,8,9,11,12,13,14,17,18,21,22,24,25,26,27,28,30,32,33,35,36,38,39,41,42,43,44,45,46,48,49,50';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 17 <br>2,3,4,6,7,10,15,16,19,20,23,29,31,34,37,40,47';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260814 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260814 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>14</strong> miembros: 34 <strong>control</strong><br>0,1,5,8,9,11,12,13,14,17,18,21,22,24,25,26,27,28,30,32,33,35,36,38,39,41,42,43,44,45,46,48,49,50';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260814 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 17 <br>2,3,4,6,7,10,15,16,19,20,23,29,31,34,37,40,47';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260814 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260814 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>14</strong> miembros: 34 <strong>control</strong><br>0,1,5,8,9,11,12,13,14,17,18,21,22,24,25,26,27,28,30,32,33,35,36,38,39,41,42,43,44,45,46,48,49,50';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260814 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 17 <br>2,3,4,6,7,10,15,16,19,20,23,29,31,34,37,40,47';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>14</strong> miembros: 34 <strong>control</strong><br>0,1,5,8,9,11,12,13,14,17,18,21,22,24,25,26,27,28,30,32,33,35,36,38,39,41,42,43,44,45,46,48,49,50';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 17 <br>2,3,4,6,7,10,15,16,19,20,23,29,31,34,37,40,47';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>14</strong> miembros: 34 <strong>control</strong><br>0,1,5,8,9,11,12,13,14,17,18,21,22,24,25,26,27,28,30,32,33,35,36,38,39,41,42,43,44,45,46,48,49,50';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 17 <br>2,3,4,6,7,10,15,16,19,20,23,29,31,34,37,40,47';}
}
